#ifndef __QTCURVECONFIG_H__
#define __QTCURVECONFIG_H__

/*
  QtCurve (C) Craig Drummond, 2004 Craig.Drummond@lycos.co.uk


  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files(the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.
*/

#define QTC_COMMON_ONLY_COVERTERS
#define QTC_CONFIG_DIALOG
#include <qtcurveconfigbase.h>
#include <klistview.h>
#include "../common.h"

class KConfig;
class KPushButton;

class QtCurveConfig : public QtCurveConfigBase
{
    Q_OBJECT

    public:

    class ListViewItem : public KListViewItem
    {
        public:

        ListViewItem(const Options &o, KListView *parent, bool t=false);
        virtual ~ListViewItem() { }

        QString key(int column, bool ascending) const;

        Options opts;
        bool    top;
	};

    public:

    QtCurveConfig(QWidget *parent);
    ~QtCurveConfig();

    signals:

    void changed(bool);

    public slots:

    void save();
    void defaults();

    private slots:

    void borderToggled();
    void highlightEditsToggled();
    void roundToggled();
    void updateChanged();
    void emboldenToggled();
    void dbiChanged();
    void lvChanged();
    void shadeSlidersChanged();
    void shadeMenubarsChanged();
    void lvHeaderColorChanged();
    void saveStyle();
    void deleteStyle();
    void importStyle();
    void exportStyle();
    void setVersion();
    void setVersion(QListViewItem *item);

    private:

    void saveStyle(const QString &title, Options &opts);
    bool saveStyle(KConfig &cfg, const Options &opts);
    bool loadOptions(const QString &file, Options &opts);
    void setOptions(Options &opts);
    void setWidgetOptions(const Options &opts);
    void loadStandardStyles();
    bool settingsChanged();

    private:

    ListViewItem *currentStyle,
                 *defaultStyle;
    KPushButton  *delBtn;
};

#endif
